<?php

/**
 * OpenKM, Open Knowledge Management System S.L.  (http://www.openkm.com)
 * Copyright (c) 2006-2018
 *
 * No bytes were intentionally harmed during the development of this application.
 *
 * This program is commercial software; you can use it under the terms of the
 * EULA - OpenKM SDK End User License Agreement as published by OpenKM Knowledge Management System S.L.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * EULA - OpenKM SDK End User License Agreement for more details:
 * http://docs.openkm.com/kcenter/view/licenses/eula-openkm-sdk-end-user-license-agreement.html
 */

namespace openkm\definition;

/**
 * BaseWorkflow
 *
 * @author sochoa
 */
interface BaseTask {

    public function createTask($subject, $start, $end, $statusId, $projectId, $typeId, $description, $usersId = [], $rolesId = []);

    public function findTask($taskId);

    public function deleteTask($taskId);

    public function getAssigned($projectId, $typeId, $statusId, $order, $offset, $limit);

    public function getActive($projectId, $typeId, $statusId, $order, $offset, $limit);

    public function getFinished($projectId, $typeId, $statusId, $order, $offset, $limit);

    public function findStatus($statusId);

    public function findProject($projectId);

    public function findType($typeId);

    public function findNote($noteId);

    public function getStatuses();

    public function getProjects($filterByActive);

    public function getTypes($filterByActive);

    public function getNotes($taskId);
}

?>
